@@ -4,6 +4,7 @@ extend TiddlyWiki serialization to optionally use beta release
 activated via "twrelease=beta" URL parameter
 """
 
+from tiddlyweb.util import read_utf8_file
 from tiddlywebwiki.serialization import Serialization as WikiSerialization
 
 
@@ -13,14 +14,7 @@ class Serialization(WikiSerialization):
         release = self.environ.get('tiddlyweb.query', {}).get(
                 'twrelease', [False])[0]
         if release == 'beta':
-            return _read_file(
+            return read_utf8_file(
                     self.environ['tiddlyweb.config']['base_tiddlywiki_beta'])
         else:
-            return WikiSerialization._get_wiki(self) # XXX: inelegant?
-
-
-def _read_file(path):
-    f = open(path)
-    contents = f.read()
-    f.close()
-    return unicode(contents, 'utf-8')
+            return WikiSerialization._get_wiki(self)  # XXX: inelegant?
